pub struct StreamingRows<'a> { /* private fields */ }Expand description
Streaming row access for FR-7 compliance.
This struct provides access to query results in a streaming fashion,
where the transaction is kept alive for the duration of row iteration.
The lifetime 'a is tied to the transaction scope.
Implementations
Sourceimpl<'a> StreamingRows<'a>
impl<'a> StreamingRows<'a>