pub enum Error {
Show 20 variants
Core(Error),
Sql(SqlError),
TxnCompleted,
CatalogNotFound(String),
CatalogAlreadyExists(String),
CatalogNotEmpty(String),
NamespaceNotFound(String, String),
NamespaceAlreadyExists(String, String),
NamespaceNotEmpty(String, String),
TableNotFound(String),
TableAlreadyExists(String),
IndexNotFound(String),
CannotDeleteDefault(String),
SchemaRequired,
StorageRootRequired,
TxnReadOnly,
InvalidTransactionId(String),
NotInMemoryMode,
UnsupportedDataSourceFormat(String),
CatalogLockPoisoned,
}Expand description
The error type for embedded database operations.
Variants
Core(Error)
An error from the underlying core storage engine.
Sql(SqlError)
An error from the SQL execution pipeline.
TxnCompleted
The transaction has already been completed and cannot be used.
CatalogNotFound(String)
Catalog が見つかりません。
CatalogAlreadyExists(String)
Catalog が既に存在します。
CatalogNotEmpty(String)
Catalog が空ではありません。
NamespaceNotFound(String, String)
Namespace が見つかりません。
NamespaceAlreadyExists(String, String)
Namespace が既に存在します。
NamespaceNotEmpty(String, String)
Namespace が空ではありません。
TableNotFound(String)
The requested table was not found or is invalid.
TableAlreadyExists(String)
Table が既に存在します。
IndexNotFound(String)
Index が見つかりません。
CannotDeleteDefault(String)
default オブジェクトは削除できません。
SchemaRequired
Managed テーブルにはスキーマが必要です。
StorageRootRequired
External テーブルには storage_root が必要です。
TxnReadOnly
トランザクションは read-only です。
InvalidTransactionId(String)
Transaction ID is invalid or missing.
NotInMemoryMode
The operation requires in-memory columnar mode.
UnsupportedDataSourceFormat(String)
The requested data source format is not supported.
CatalogLockPoisoned
The catalog store lock was poisoned.
Implementations