pub struct OwnedReadSession { /* private fields */ }Expand description
A read-only session that owns a transaction until a stream terminal action releases it.
Implementations
Sourceimpl OwnedReadSession
impl OwnedReadSession
Sourcepub fn new(
transaction: Box<dyn OwnedKVTransaction>,
) -> Result<OwnedReadSession, Error>
pub fn new( transaction: Box<dyn OwnedKVTransaction>, ) -> Result<OwnedReadSession, Error>
Wrap a backend-owned read-only transaction.
Sourcepub fn status(&self) -> OwnedReadSessionStatus
pub fn status(&self) -> OwnedReadSessionStatus
Return the current lifecycle state.
Sourcepub fn acquire_lease(&self) -> Result<OwnedReadLease, Error>
pub fn acquire_lease(&self) -> Result<OwnedReadLease, Error>
Acquire the only lease allowed to advance this read session.
Sourcepub fn close(&self) -> Result<OwnedReadSessionStatus, Error>
pub fn close(&self) -> Result<OwnedReadSessionStatus, Error>
Close this session. Closing is idempotent after any terminal state.